import { Fragment, useState, useEffect } from '@wordpress/element';
import { isEmpty } from 'lodash';
import { DashCheck, DashClose, DashEye } from './dashboard-icons';
import { __, sprintf } from '@wordpress/i18n';

const DashboardPage = () => {
    const {
        demo,
        pages,
        domain,
        versions,
    } = window['GutenThemeConfig'];

    const [gutenverse, setGutenverse] = useState(null);
    const [loading, setLoading] = useState(true);
    const [popupImg, setPopupImg] = useState('');
    const [openPopup, setOpenPopup] = useState(false);

    useEffect(() => {
        wp.apiFetch({
            path: 'wp/v2/plugins/gutenverse/gutenverse',
            method: 'GET',
        }).then(data => {
            !isEmpty(data) && setGutenverse(data);
        }).catch(() => {
            setGutenverse(false);
        }).finally(() => {
            setLoading(false);
        });
    }, []);

    const activatePlugin = () => {
        setLoading(true);

        if (!isEmpty(gutenverse) && gutenverse['status'] === 'active') {
            window.open('', '_self');
            return;
        }

        let path = 'wp/v2/plugins';
        let data = {
            slug: 'gutenverse',
            status: 'active'
        };

        if (!isEmpty(gutenverse) && gutenverse['status'] === 'inactive') {
            path = 'wp/v2/plugins/gutenverse/gutenverse';
            data = {
                status: 'active'
            };
        }

        wp.apiFetch({
            path,
            method: 'POST',
            data
        }).finally(() => {
            setLoading(false);
            location.reload();
        });
    };

    const onOpen = img => {
        setOpenPopup(true);
        setPopupImg(img);
    };

    const onClose = () => {
        setOpenPopup(false);
    };

    const comparisons = [
        __('Advanced Templates', domain),
        __('Responsive Styling', domain),
        __('Variety of Fonts', domain),
        __('Icon Library', domain),
        __('Animation Effects', domain),
        __('Form Builder', domain),
    ];

    const benefits = [
        __('Modern and clean design', domain),
        __('5+ Ready to use templates', domain),
        __('15+ template parts', domain),
        __('Fully responsive layout', domain),
        __('Fully customizable', domain),
    ];

    return <Fragment>
        <section>
            <div className="container templates">
                <div className="thumbnail">
                    {Object.keys(pages).map(key => {
                        return <div key={key} className="image" onClick={() => onOpen(pages[key])}>
                            <img src={pages[key]} alt="image" width="400" height="300" />
                            <div className="hover"><DashEye /></div>
                        </div>;
                    })}
                </div>
                <div className="content">
                    <h2 className="title">{__('Get Advanced Templates for Free!', domain)}</h2>
                    <p className="description">{__('By just installing and activate Gutenverse plugin you will be able to use this theme\'s advanced templates. With Gutenverse plugin installed, you gain access to both advance version of templates and block patterns for free which all built using Gutenverse blocks.', domain)}</p>
                    <div className="notes">
                        <h4>
                            <svg width="16" height="16" viewBox="0 0 16 16" fill="none" xmlns="http://www.w3.org/2000/svg">
                                <path d="M8 14C9.5913 14 11.1174 13.3679 12.2426 12.2426C13.3679 11.1174 14 9.5913 14 8C14 6.4087 13.3679 4.88258 12.2426 3.75736C11.1174 2.63214 9.5913 2 8 2C6.4087 2 4.88258 2.63214 3.75736 3.75736C2.63214 4.88258 2 6.4087 2 8C2 9.5913 2.63214 11.1174 3.75736 12.2426C4.88258 13.3679 6.4087 14 8 14ZM8 15.5C3.85775 15.5 0.5 12.1422 0.5 8C0.5 3.85775 3.85775 0.5 8 0.5C12.1422 0.5 15.5 3.85775 15.5 8C15.5 12.1422 12.1422 15.5 8 15.5ZM7.25 11H8.75V12.5H7.25V11ZM7.25 3.5H8.75V9.5H7.25V3.5Z" fill="#ECB905" />
                            </svg>
                            {__('Important Notice', domain)}
                        </h4>
                        <ul>
                            <li>{__('Clicking the button will both install and activate Gutenverse plugin and templates for this theme. Please first backup your current templates if you have any changes to it.', domain)}</li>
                            <li>{sprintf(__('Gutenverse version %s & above required!', domain), versions?.gutenverse)}</li>
                        </ul>
                    </div>
                    <div className="theme-buttons">
                        {!isEmpty(gutenverse) && gutenverse['status'] === 'active' ? <div className="theme-button active">
                            {loading ? <div className="loader"></div> : __('Gutenverse Plugin Installed', domain)}
                        </div> : !isEmpty(gutenverse) && gutenverse['status'] === 'inactive' ? <div className="theme-button" onClick={activatePlugin}>
                            {loading ? <div className="loader"></div> : __('Activate Gutenverse Plugin', domain)}
                        </div> : <div className="theme-button" onClick={activatePlugin}>
                            {loading ? <div className="loader"></div> : __('Install Gutenverse Plugin', domain)}
                        </div>}
                        <a className="theme-link" href={demo} target="_blank" rel="noreferrer">{__('View Live Demo →', domain)}</a>
                    </div>
                </div>
            </div>
        </section>
        <section>
            <div className="container comparisons">
                <h2 className="title">{__('Comparison Gutenverse VS WordPress Core', domain)}</h2>
                <table>
                    <thead>
                        <tr className="thead_tr">
                            <th className="thead_th">{ }</th>
                            <th className="thead_th">{__('Gutenverse Version', domain)}</th>
                            <th className="thead_th">{__('WordPress Core', domain)}</th>
                        </tr>
                    </thead>
                    <tbody>
                        {comparisons.map((feature, key) => {
                            return <tr key={key}>
                                <td className="tbody_td">{feature}</td>
                                <td className="tbody_td center"><DashCheck /></td>
                                <td className="tbody_td center"><DashClose /></td>
                            </tr>;
                        })}
                    </tbody>
                </table>
            </div>
            <div className="container benefits">
                <h2 className="title">{__('Benefits for Installing nettiz\'s Gutenverse Version', domain)}</h2>
                <p className="description">{__('You can customize your website instantly with powerful and lightweight add-ons plugin for Gutenberg/FSE.', domain)}</p>
                <div className="features">
                    <h4>{__('Features', domain)}</h4>
                    <ul>
                        {benefits.map((feature, key) => {
                            return <li key={key}>{feature}</li>;
                        })}
                    </ul>
                </div>
            </div>
        </section>
        <div className={`popup ${!openPopup ? 'hide' : ''}`} onClick={onClose}>
            <img src={popupImg} alt="image" />
        </div>
    </Fragment>;
};

export default DashboardPage;