<?php
/**
 * Init Configuration
 *
 * @author Jegtheme
 * @package nettiz
 */

namespace Nettiz;

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

/**
 * Init Class
 *
 * @package nettiz
 */
class Init {

	/**
	 * Instance variable
	 *
	 * @var $instance
	 */
	private static $instance;

	/**
	 * Class instance.
	 *
	 * @return Init
	 */
	public static function instance() {
		if ( null === static::$instance ) {
			static::$instance = new static();
		}

		return static::$instance;
	}

	/**
	 * Class constructor.
	 */
	private function __construct() {
		$this->load_hooks();
		$this->init_instance();
	}

	/**
	 * Load initial hooks.
	 */
	private function load_hooks() {
		add_action( 'init', array( $this, 'register_block_patterns' ), 9 );
		add_action( 'admin_menu', array( $this, 'admin_menu' ) );
		add_action( 'admin_enqueue_scripts', array( $this, 'dashboard_scripts' ) );

		add_filter( 'gutenverse_template_path', array( $this, 'template_path' ), null, 3 );
		add_filter( 'gutenverse_themes_template', array( $this, 'add_template' ), 10, 2 );
		add_filter( 'gutenverse_block_config', array( $this, 'default_font' ), 10 );
		add_filter( 'gutenverse_font_header', array( $this, 'default_header_font' ) );
		add_filter( 'gutenverse_global_css', array( $this, 'global_header_style' ) );
	}

	public function init_instance() {
		new Asset_Enqueue();
	}

	/**
	 * Generate Global Font
	 *
	 * @param string $value  Value of the option.
	 *
	 * @return string
	 */
	public function global_header_style( $value ) {
		$theme_name      = get_stylesheet();
		$global_variable = get_option( 'gutenverse-global-variable-font-' . $theme_name );

		if ( empty( $global_variable ) && function_exists( 'gutenverse_global_font_style_generator' ) ) {
			$font_variable = $this->default_font_variable();
			$value        .= \gutenverse_global_font_style_generator( $font_variable );
		}

		return $value;
	}

	/**
	 * Header Font.
	 *
	 * @param mixed $value  Value of the option.
	 *
	 * @return mixed Value of the option.
	 */
	public function default_header_font( $value ) {
		if ( ! $value ) {
			$value = array(
				array(
					'value'  => 'Alfa Slab One',
					'type'   => 'google',
					'weight' => 'bold',
				),
			);
		}

		return $value;
	}

	/**
	 * Alter Default Font.
	 *
	 * @param array $config Array of Config.
	 *
	 * @return array
	 */
	public function default_font( $config ) {
		if ( empty( $config['globalVariable']['fonts'] ) ) {
			$config['globalVariable']['fonts'] = $this->default_font_variable();

			return $config;
		}

		if ( ! empty( $config['globalVariable']['fonts'] ) ) {
			// Handle existing fonts.
			$theme_name   = get_stylesheet();
			$initial_font = get_option( 'gutenverse-font-init-' . $theme_name );

			if ( ! $initial_font ) {
				$config['globalVariable']['fonts'] = array_merge( $config['globalVariable']['fonts'], $this->default_font_variable() );
				update_option( 'gutenverse-font-init-' . $theme_name, true );
			}
		}

		return $config;
	}

	/**
	 * Default Font Variable.
	 *
	 * @return array
	 */
	public function default_font_variable() {
		return array(
			array(
				'id'   => 'qv714R',
				'name' => 'H1',
				'font' =>
				array(
					'font'       =>
					array(
						'label' => 'Muli',
						'value' => 'Muli',
						'type'  => 'google',
					),
					'size'       =>
					array(
						'Desktop' =>
						array(
							'point' => '76',
							'unit'  => 'px',
						),
						'Mobile'  =>
						array(
							'point' => '42',
							'unit'  => 'px',
						),
						'Tablet'  =>
						array(
							'point' => '70',
							'unit'  => 'px',
						),
					),
					'lineHeight' =>
					array(
						'Desktop' =>
						array(
							'unit'  => 'em',
							'point' => '1.2',
						),
						'Tablet'  =>
						array(
							'unit'  => 'em',
							'point' => '1.2',
						),
						'Mobile'  =>
						array(
							'unit'  => 'em',
							'point' => '1.2',
						),
					),
					'weight'     => '700',
				),
			),
			array(
				'id'   => 'Epnwe1',
				'name' => 'H1 Hero Title',
				'font' =>
				array(
					'font'       =>
					array(
						'label' => 'Muli',
						'value' => 'Muli',
						'type'  => 'google',
					),
					'size'       =>
					array(
						'Desktop' =>
						array(
							'point' => '64',
							'unit'  => 'px',
						),
						'Tablet'  =>
						array(
							'point' => '64',
							'unit'  => 'px',
						),
						'Mobile'  =>
						array(
							'point' => '38',
							'unit'  => 'px',
						),
					),
					'lineHeight' =>
					array(
						'Desktop' =>
						array(
							'unit'  => 'em',
							'point' => '1',
						),
						'Tablet'  =>
						array(
							'unit'  => 'em',
							'point' => '1.2',
						),
						'Mobile'  =>
						array(
							'unit'  => 'em',
							'point' => '1.2',
						),
					),
					'weight'     => '700',
				),
			),
			array(
				'id'   => 'QQwswe',
				'name' => 'H2',
				'font' =>
				array(
					'font'       =>
					array(
						'label' => 'Muli',
						'value' => 'Muli',
						'type'  => 'google',
					),
					'size'       =>
					array(
						'Desktop' =>
						array(
							'point' => '44',
							'unit'  => 'px',
						),
						'Mobile'  =>
						array(
							'point' => '36',
							'unit'  => 'px',
						),
						'Tablet'  =>
						array(
							'point' => '44',
							'unit'  => 'px',
						),
					),
					'lineHeight' =>
					array(
						'Desktop' =>
						array(
							'unit'  => 'em',
							'point' => '1.2',
						),
						'Tablet'  =>
						array(
							'unit'  => 'em',
							'point' => '1.1',
						),
						'Mobile'  =>
						array(
							'unit'  => 'em',
							'point' => '1.2',
						),
					),
					'weight'     => '700',
				),
			),
			array(
				'id'   => '6O91KP',
				'name' => 'H2 Alt',
				'font' =>
				array(
					'font'       =>
					array(
						'label' => 'Muli',
						'value' => 'Muli',
						'type'  => 'google',
					),
					'size'       =>
					array(
						'Desktop' =>
						array(
							'point' => '36',
							'unit'  => 'px',
						),
					),
					'lineHeight' =>
					array(
						'Desktop' =>
						array(
							'unit'  => 'em',
							'point' => '1',
						),
					),
					'weight'     => '700',
				),
			),
			array(
				'id'   => 'T7W6bW',
				'name' => 'H3',
				'font' =>
				array(
					'font'       =>
					array(
						'label' => 'Muli',
						'value' => 'Muli',
						'type'  => 'google',
					),
					'size'       =>
					array(
						'Desktop' =>
						array(
							'point' => '24',
							'unit'  => 'px',
						),
						'Mobile'  =>
						array(
							'point' => '22',
							'unit'  => 'px',
						),
						'Tablet'  =>
						array(
							'point' => '24',
							'unit'  => 'px',
						),
					),
					'lineHeight' =>
					array(
						'Desktop' =>
						array(
							'unit'  => 'em',
							'point' => '1.3',
						),
					),
					'weight'     => '700',
				),
			),
			array(
				'id'   => 'UyffT5',
				'name' => 'H4',
				'font' =>
				array(
					'font'       =>
					array(
						'label' => 'Muli',
						'value' => 'Muli',
						'type'  => 'google',
					),
					'size'       =>
					array(
						'Desktop' =>
						array(
							'point' => '22',
							'unit'  => 'px',
						),
						'Mobile'  =>
						array(
							'point' => '18',
							'unit'  => 'px',
						),
					),
					'lineHeight' =>
					array(
						'Desktop' =>
						array(
							'unit'  => 'em',
							'point' => '1',
						),
						'Mobile'  =>
						array(
							'unit'  => 'em',
							'point' => '1.2',
						),
					),
					'weight'     => '700',
				),
			),
			array(
				'id'   => 'p5goW1',
				'name' => 'H5',
				'font' =>
				array(
					'font'       =>
					array(
						'label' => 'Heebo',
						'value' => 'Heebo',
						'type'  => 'google',
					),
					'size'       =>
					array(
						'Desktop' =>
						array(
							'point' => '18',
							'unit'  => 'px',
						),
						'Tablet'  =>
						array(
							'point' => '18',
							'unit'  => 'px',
						),
						'Mobile'  =>
						array(
							'point' => '18',
							'unit'  => 'px',
						),
					),
					'lineHeight' =>
					array(
						'Desktop' =>
						array(
							'unit'  => 'em',
							'point' => '1',
						),
						'Tablet'  =>
						array(
							'unit'  => 'em',
							'point' => '1',
						),
						'Mobile'  =>
						array(
							'unit'  => 'em',
							'point' => '1',
						),
					),
					'weight'     => '500',
				),
			),
			array(
				'id'   => 'kxqTXQ',
				'name' => 'Body Hero',
				'font' =>
				array(
					'font'       =>
					array(
						'label' => 'Heebo',
						'value' => 'Heebo',
						'type'  => 'google',
					),
					'size'       =>
					array(
						'Desktop' =>
						array(
							'point' => '18',
							'unit'  => 'px',
						),
						'Mobile'  =>
						array(
							'point' => '16',
							'unit'  => 'px',
						),
					),
					'lineHeight' =>
					array(
						'Desktop' =>
						array(
							'unit'  => 'em',
							'point' => '1.5',
						),
					),
					'weight'     => '400',
				),
			),
			array(
				'id'   => 'fYWuaq',
				'name' => 'Body Text',
				'font' =>
				array(
					'font'       =>
					array(
						'label' => 'Heebo',
						'value' => 'Heebo',
						'type'  => 'google',
					),
					'size'       =>
					array(
						'Desktop' =>
						array(
							'point' => '16',
							'unit'  => 'px',
						),
						'Tablet'  =>
						array(
							'point' => '16',
							'unit'  => 'px',
						),
						'Mobile'  =>
						array(
							'point' => '14',
							'unit'  => 'px',
						),
					),
					'lineHeight' =>
					array(
						'Desktop' =>
						array(
							'unit'  => 'em',
							'point' => '1.5',
						),
						'Tablet'  =>
						array(
							'unit'  => 'em',
							'point' => '1.5',
						),
						'Mobile'  =>
						array(
							'unit'  => 'em',
							'point' => '1.5',
						),
					),
					'weight'     => '400',
				),
			),
			array(
				'id'   => 'bozuE2',
				'name' => 'Nav Menu',
				'font' =>
				array(
					'font'       =>
					array(
						'label' => 'Muli',
						'value' => 'Muli',
						'type'  => 'google',
					),
					'size'       =>
					array(
						'Desktop' =>
						array(
							'point' => '16',
							'unit'  => 'px',
						),
						'Tablet'  =>
						array(
							'point' => '16',
							'unit'  => 'px',
						),
						'Mobile'  =>
						array(
							'point' => '16',
							'unit'  => 'px',
						),
					),
					'lineHeight' =>
					array(
						'Desktop' =>
						array(
							'unit'  => 'em',
							'point' => '1.2',
						),
						'Tablet'  =>
						array(
							'unit'  => 'em',
							'point' => '1.2',
						),
						'Mobile'  =>
						array(
							'unit'  => 'em',
							'point' => '1.2',
						),
					),
					'weight'     => '700',
				),
			),
			array(
				'id'   => '8QeMLF',
				'name' => 'Text Icon Box',
				'font' =>
				array(
					'font'       =>
					array(
						'label' => 'Heebo',
						'value' => 'Heebo',
						'type'  => 'google',
					),
					'size'       =>
					array(
						'Desktop' =>
						array(
							'point' => '16',
							'unit'  => 'px',
						),
						'Tablet'  =>
						array(
							'point' => '18',
							'unit'  => 'px',
						),
						'Mobile'  =>
						array(
							'point' => '18',
							'unit'  => 'px',
						),
					),
					'lineHeight' =>
					array(
						'Desktop' =>
						array(
							'unit'  => 'em',
							'point' => '1.7',
						),
						'Tablet'  =>
						array(
							'unit'  => 'em',
							'point' => '1.7',
						),
						'Mobile'  =>
						array(
							'unit'  => 'em',
							'point' => '1.7',
						),
					),
					'weight'     => '400',
				),
			),
			array(
				'id'   => '9b2Huo',
				'name' => 'Quotes',
				'font' =>
				array(
					'font'       =>
					array(
						'label' => 'Muli',
						'value' => 'Muli',
						'type'  => 'google',
					),
					'size'       =>
					array(
						'Desktop' =>
						array(
							'point' => '28',
							'unit'  => 'px',
						),
						'Mobile'  =>
						array(
							'point' => '22',
							'unit'  => 'px',
						),
						'Tablet'  =>
						array(
							'point' => '28',
							'unit'  => 'px',
						),
					),
					'lineHeight' =>
					array(
						'Desktop' =>
						array(
							'unit'  => 'em',
							'point' => '1.5',
						),
						'Tablet'  =>
						array(
							'unit'  => 'em',
							'point' => '1.5',
						),
						'Mobile'  =>
						array(
							'unit'  => 'em',
							'point' => '1.5',
						),
					),
					'weight'     => '600',
				),
			),
			array(
				'id'   => '8seM0M',
				'name' => '404',
				'font' =>
				array(
					'font'       =>
					array(
						'label' => 'Muli',
						'value' => 'Muli',
						'type'  => 'google',
					),
					'size'       =>
					array(
						'Desktop' =>
						array(
							'point' => '160',
							'unit'  => 'px',
						),
						'Tablet'  =>
						array(
							'point' => '140',
							'unit'  => 'px',
						),
						'Mobile'  =>
						array(
							'point' => '80',
							'unit'  => 'px',
						),
					),
					'weight'     => '700',
					'lineHeight' =>
					array(
						'Desktop' =>
						array(
							'unit'  => 'em',
							'point' => '1',
						),
						'Tablet'  =>
						array(
							'unit'  => 'em',
							'point' => '1',
						),
						'Mobile'  =>
						array(
							'unit'  => 'em',
							'point' => '1',
						),
					),
				),
			),
			array(
				'id'   => 'G6RtcK',
				'name' => 'Button',
				'font' =>
				array(
					'font'       =>
					array(
						'label' => 'Muli',
						'value' => 'Muli',
						'type'  => 'google',
					),
					'size'       =>
					array(
						'Desktop' =>
						array(
							'point' => '16',
							'unit'  => 'px',
						),
						'Tablet'  =>
						array(
							'point' => '16',
							'unit'  => 'px',
						),
						'Mobile'  =>
						array(
							'point' => '16',
							'unit'  => 'px',
						),
					),
					'lineHeight' =>
					array(
						'Desktop' =>
						array(
							'unit'  => 'em',
							'point' => '1',
						),
						'Tablet'  =>
						array(
							'unit'  => 'em',
							'point' => '',
						),
						'Mobile'  =>
						array(
							'unit'  => 'em',
							'point' => '1',
						),
					),
					'weight'     => '700',
				),
			),
			array(
				'id'   => 'J9sBcy',
				'name' => 'Button Alt',
				'font' =>
				array(
					'font'       =>
					array(
						'label' => 'Muli',
						'value' => 'Muli',
						'type'  => 'google',
					),
					'size'       =>
					array(
						'Desktop' =>
						array(
							'point' => '14',
							'unit'  => 'px',
						),
						'Tablet'  =>
						array(
							'point' => '14',
							'unit'  => 'px',
						),
						'Mobile'  =>
						array(
							'point' => '14',
							'unit'  => 'px',
						),
					),
					'lineHeight' =>
					array(
						'Desktop' =>
						array(
							'unit'  => 'em',
							'point' => '1',
						),
						'Tablet'  =>
						array(
							'unit'  => 'em',
							'point' => '1',
						),
						'Mobile'  =>
						array(
							'unit'  => 'em',
							'point' => '1',
						),
					),
					'weight'     => '600',
				),
			),
			array(
				'id'   => 'lFjpsI',
				'name' => 'Text Editor',
				'font' =>
				array(
					'font'       =>
					array(
						'label' => 'Heebo',
						'value' => 'Heebo',
						'type'  => 'google',
					),
					'size'       =>
					array(
						'Desktop' =>
						array(
							'point' => '14',
							'unit'  => 'px',
						),
						'Tablet'  =>
						array(
							'point' => '14',
							'unit'  => 'px',
						),
						'Mobile'  =>
						array(
							'point' => '14',
							'unit'  => 'px',
						),
					),
					'weight'     => '400',
					'lineHeight' =>
					array(
						'Desktop' =>
						array(
							'unit'  => 'em',
							'point' => '1.5',
						),
						'Tablet'  =>
						array(
							'unit'  => 'em',
							'point' => '1.5',
						),
						'Mobile'  =>
						array(
							'unit'  => 'em',
							'point' => '1.5',
						),
					),
				),
			),
			array(
				'id'   => '3otnFx',
				'name' => 'Quotes Single',
				'font' =>
				array(
					'font'       =>
					array(
						'label' => 'Muli',
						'value' => 'Muli',
						'type'  => 'google',
					),
					'size'       =>
					array(
						'Desktop' =>
						array(
							'point' => '20',
							'unit'  => 'px',
						),
						'Tablet'  =>
						array(
							'point' => '18',
							'unit'  => 'px',
						),
						'Mobile'  =>
						array(
							'point' => '16',
							'unit'  => 'px',
						),
					),
					'lineHeight' =>
					array(
						'Desktop' =>
						array(
							'unit'  => 'em',
							'point' => '1.5',
						),
						'Tablet'  =>
						array(
							'unit'  => 'em',
							'point' => '1.5',
						),
						'Mobile'  =>
						array(
							'unit'  => 'em',
							'point' => '1.5',
						),
					),
					'weight'     => '500',
				),
			),
			array(
				'id'   => 'eV4M1w',
				'name' => 'Fun Fact',
				'font' =>
				array(
					'font'       =>
					array(
						'label' => 'Muli',
						'value' => 'Muli',
						'type'  => 'google',
					),
					'size'       =>
					array(
						'Desktop' =>
						array(
							'point' => '36',
							'unit'  => 'px',
						),
						'Tablet'  =>
						array(
							'point' => '32',
							'unit'  => 'px',
						),
					),
					'lineHeight' =>
					array(
						'Desktop' =>
						array(
							'unit'  => 'em',
							'point' => '1',
						),
						'Tablet'  =>
						array(
							'unit'  => 'em',
							'point' => '1',
						),
					),
					'weight'     => '700',
				),
			),
			array(
				'id'   => '4IN0jt',
				'name' => 'Category',
				'font' =>
				array(
					'font'       =>
					array(
						'label' => 'Muli',
						'value' => 'Muli',
						'type'  => 'google',
					),
					'size'       =>
					array(
						'Desktop' =>
						array(
							'point' => '12',
							'unit'  => 'px',
						),
					),
					'lineHeight' =>
					array(
						'Desktop' =>
						array(
							'point' => '1',
							'unit'  => 'px',
						),
					),
					'weight'     => '700',
				),
			),
			array(
				'id'   => 'jvvTOO',
				'name' => 'Input Style',
				'font' =>
				array(
					'font'       =>
					array(
						'label' => 'Muli',
						'value' => 'Muli',
						'type'  => 'google',
					),
					'size'       =>
					array(
						'Desktop' =>
						array(
							'point' => '16',
							'unit'  => 'px',
						),
						'Tablet'  =>
						array(
							'point' => '16',
							'unit'  => 'px',
						),
						'Mobile'  =>
						array(
							'point' => '15',
							'unit'  => 'px',
						),
					),
					'lineHeight' =>
					array(
						'Desktop' =>
						array(
							'unit'  => 'em',
							'point' => '1',
						),
						'Tablet'  =>
						array(
							'unit'  => 'em',
							'point' => '1',
						),
						'Mobile'  =>
						array(
							'unit'  => 'em',
							'point' => '1',
						),
					),
					'weight'     => '600',
				),
			),
			array(
				'id'   => 'xLcQuj',
				'name' => 'H2 Pop Up',
				'font' =>
				array(
					'font'       =>
					array(
						'label' => 'Muli',
						'value' => 'Muli',
						'type'  => 'google',
					),
					'size'       =>
					array(
						'Desktop' =>
						array(
							'point' => '36',
							'unit'  => 'px',
						),
						'Tablet'  =>
						array(
							'point' => '36',
							'unit'  => 'px',
						),
						'Mobile'  =>
						array(
							'point' => '30',
							'unit'  => 'px',
						),
					),
					'lineHeight' =>
					array(
						'Desktop' =>
						array(
							'unit'  => 'em',
							'point' => '1',
						),
						'Tablet'  =>
						array(
							'unit'  => 'em',
							'point' => '1',
						),
						'Mobile'  =>
						array(
							'unit'  => 'em',
							'point' => '1',
						),
					),
					'weight'     => '700',
				),
			),
		);
	}



	/**
	 * Add Template to Editor.
	 *
	 * @param array $template_files Path to Template File.
	 * @param array $template_type Template Type.
	 *
	 * @return array
	 */
	public function add_template( $template_files, $template_type ) {
		$directory = get_template_directory();

		if ( 'wp_template' === $template_type ) {
			$new_templates = array(
				'about',
				'service',
				'pricing',
				'our-team',
				'faq',
				'blog',
				'contact',
				'page',
				'single',
				'archive',
				'search',
				'404',
				'index',
				'home',
				'basic-template',
			);

			foreach ( $new_templates as $template ) {
				$template_files[] = array(
					'slug'  => $template,
					'path'  => $directory . "/gutenverse-templates/templates/{$template}.html",
					'theme' => get_template(),
					'type'  => 'wp_template',
				);
			}
		}

		return $template_files;
	}

	/**
	 * Use gutenverse template file instead.
	 *
	 * @param string $template_file Path to Template File.
	 * @param string $theme_slug Theme Slug.
	 * @param string $template_slug Template Slug.
	 *
	 * @return string
	 */
	public function template_path( $template_file, $theme_slug, $template_slug ) {
		$directory = get_template_directory();

		switch ( $template_slug ) {
			case 'about':
				return $directory . '/gutenverse-templates/templates/about.html';
			case 'service':
				return $directory . '/gutenverse-templates/templates/service.html';
			case 'pricing':
				return $directory . '/gutenverse-templates/templates/pricing.html';
			case 'our-team':
				return $directory . '/gutenverse-templates/templates/our-team.html';
			case 'faq':
				return $directory . '/gutenverse-templates/templates/faq.html';
			case 'blog':
				return $directory . '/gutenverse-templates/templates/blog.html';
			case 'contact':
				return $directory . '/gutenverse-templates/templates/contact.html';
			case 'header':
				return $directory . '/gutenverse-templates/parts/header.html';
			case 'footer':
				return $directory . '/gutenverse-templates/parts/footer.html';
			case 'page':
				return $directory . '/gutenverse-templates/templates/page.html';
			case 'single':
				return $directory . '/gutenverse-templates/templates/single.html';
			case 'archive':
				return $directory . '/gutenverse-templates/templates/archive.html';
			case 'search':
				return $directory . '/gutenverse-templates/templates/search.html';
			case '404':
				return $directory . '/gutenverse-templates/templates/404.html';
			case 'index':
				return $directory . '/gutenverse-templates/templates/index.html';
			case 'home':
				return $directory . '/gutenverse-templates/templates/home.html';
			case 'basic-template':
				return $directory . '/gutenverse-templates/templates/basic-template.html';
		}

		return $template_file;
	}

	/**
	 * Register Block Pattern.
	 */
	public function register_block_patterns() {
		new Block_Patterns();
	}

	/**
	 * Enqueue scripts and styles.
	 */
	public function dashboard_scripts() {
		$screen = get_current_screen();

		if ( $screen->id === 'appearance_page_nettiz-dashboard' ) {
			// enqueue css.
			wp_enqueue_style(
				'nettiz-dashboard',
				NETTIZ_URI . '/assets/css/dashboard.css',
				array(),
				NETTIZ_VERSION
			);

			// enqueue js.
			wp_enqueue_script(
				'nettiz-dashboard',
				NETTIZ_URI . '/assets/js/dashboard.js',
				array( 'wp-api-fetch' ),
				NETTIZ_VERSION,
				true
			);

			wp_localize_script( 'nettiz-dashboard', 'GutenThemeConfig', $this->theme_config() );
		}
	}

	/**
	 * Register static data to be used in theme's js file
	 */
	public function theme_config() {
		$active_plugins  = get_option( 'active_plugins' );
				$plugins = array();
		foreach ( $active_plugins as $active ) {
			$plugins[] = explode( '/', $active )[0];
		}

		return array(
			'demo'     => esc_url( 'https:/gutenverse.com/demo?name=nettiz' ),
			'pages'    => array(
				'home'    => NETTIZ_URI . '/assets/img/page-home.webp',
				'about'   => NETTIZ_URI . '/assets/img/page-about.webp',
				'service' => NETTIZ_URI . '/assets/img/page-service.webp',
				'faq'     => NETTIZ_URI . '/assets/img/page-faq.webp',
				'pricing' => NETTIZ_URI . '/assets/img/page-pricing.webp',
			),
			'domain'   => 'nettiz',
			'versions' => array(
				'gutenverse' => '1.8.5',
			),
		);
	}

	/**
	 * Add Menu
	 */
	public function admin_menu() {
		add_theme_page(
			'Theme Dashboard',
			'Theme Dashboard',
			'manage_options',
			'nettiz-dashboard',
			array( $this, 'load_dashboard' ),
			1
		);
	}

	/**
	 * Template page
	 */
	public function load_dashboard() {
		?>
			<div id="gutenverse-theme-dashboard">
			</div>
		<?php
	}
}
